==> grafana-8.2.3.tar.gz: grafana-8.2.3/docs/sources/visualizations/time-series/graph-time-series-as-points.md <==
+++
title = "Graph time series as points"
keywords = ["grafana", "time series panel", "documentation", "guide", "graph"]
aliases = ["/docs/grafana/latest/panels/visualizations/time-series/graph-time-series-as-points/"]
weight = 300
+++

# Graph time series as points

This section explains how to use Time series field options to visualize time series data as points and illustrates what the options do.

## Create the panel

1. [Add a panel]({{< relref "../../panels/add-a-panel.md" >}}). Select the [Time series]({{< relref "_index.md" >}}) visualization.
1. In the [Panel editor]({{< relref "../../panels/panel-editor.md" >}}) side pane, click **Graph styles** to expand it.
1. In Style, click **Points**.

## Style the points

Use the following field settings to refine your visualization.

Some field options will not affect the visualization until you click outside of the field option box you are editing or press Enter.

### Point size

Set the size of the points, from 1 to 40 pixels in diameter.

Point size set to 6:

![Show points point size 6 example](/static/img/docs/time-series-panel/points-graph-show-points-6-7-4.png)

Point size set to 20:

![Show points point size 20 example](/static/img/docs/time-series-panel/points-graph-show-points-20-7-4.png)

Point size set to 35:

![Show points point size 35 example](/static/img/docs/time-series-panel/points-graph-show-points-35-7-4.png)

{{< docs/shared "visualizations/stack-series-link.md" >}}

{{< docs/shared "visualizations/change-axis-link.md" >}}

==> grafana-8.5.9.tar.gz: grafana-8.5.9/docs/sources/visualizations/time-series/graph-time-series-as-points.md <==
---
aliases:
  - /docs/grafana/latest/panels/visualizations/time-series/graph-time-series-as-points/
  - /docs/grafana/latest/visualizations/time-series/graph-time-series-as-points/
keywords:
  - grafana
  - time series panel
  - documentation
  - guide
  - graph
title: Graph time series as points
weight: 300
---

# Graph time series as points

This section explains how to use Time series field options to visualize time series data as points and illustrates what the options do.

## Create the panel

1. [Add a panel]({{< relref "../../panels/working-with-panels/add-panel.md" >}}). Select the [Time series]({{< relref "_index.md" >}}) visualization.
1. In the Panel editor side pane, click **Graph styles** to expand it.
1. In Style, click **Points**.

## Style the points

Use the following field settings to refine your visualization.

Some field options will not affect the visualization until you click outside of the field option box you are editing or press Enter.

### Point size

Set the size of the points, from 1 to 40 pixels in diameter.

Point size set to 6:

![Show points point size 6 example](/static/img/docs/time-series-panel/points-graph-show-points-6-7-4.png)

Point size set to 20:

![Show points point size 20 example](/static/img/docs/time-series-panel/points-graph-show-points-20-7-4.png)

Point size set to 35:

![Show points point size 35 example](/static/img/docs/time-series-panel/points-graph-show-points-35-7-4.png)

{{< docs/shared "visualizations/stack-series-link.md" >}}

{{< docs/shared "visualizations/change-axis-link.md" >}}
